#[repr(u8)]pub enum EffectIdentifier {
Blink = 0,
Breathe = 1,
Okay = 2,
Channelchange = 11,
Finisheffect = 254,
Stopeffect = 255,
}Variants
Blink = 0
e.g., Light is turned on/off once.
Breathe = 1
e.g., Light is turned on/off over 1 second and repeated 15 times.
Okay = 2
e.g., Colored light turns green for 1 second; non-colored light flashes twice.
Channelchange = 11
e.g., Colored light turns orange for 8 seconds; non-colored light switches to the maximum brightness for 0.5s and then minimum brightness for 7.5s.
Finisheffect = 254
Complete the current effect sequence before terminating. e.g., if in the middle of a breathe effect (as above), first complete the current 1s breathe effect and then terminate the effect.
Stopeffect = 255
Terminate the effect as soon as possible.
Implementations